==> unicore-uvos-server-1.5.0-1.src.tar.gz: src/test/java/pl/edu/icm/unicore/uvos/tests/functional/AbstractTestBase.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Sep 20, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.tests.functional;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Date;
import java.util.List;

import org.junit.After;
import org.junit.Before;

import static junit.framework.Assert.*;

import pl.edu.icm.unicore.uvos.api.Group;
import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.IdentityType;
import pl.edu.icm.unicore.uvos.api.Permissions;
import pl.edu.icm.unicore.uvos.api.exceptions.UVOSException;
import pl.edu.icm.unicore.uvos.db.DB;
import pl.edu.icm.unicore.uvos.db.InitDB;
import pl.edu.icm.unicore.uvos.engine.InternalAuthorization;
import pl.edu.icm.unicore.uvos.engine.SecurityContext;
import pl.edu.icm.unicore.uvos.engine.VirtualSecurityContextImpl;
import pl.edu.icm.unicore.uvos.engine.api.UVOSAuthZInterface;
import pl.edu.icm.unicore.uvos.engine.api.UVOSManagementInterface;
import pl.edu.icm.unicore.uvos.engine.api.UVOSQueryHistoryInterface;
import pl.edu.icm.unicore.uvos.engine.api.UVOSQueryInterface;
import pl.edu.icm.unicore.uvos.server.ComponentContainer;
import pl.edu.icm.unicore.uvos.server.idresolver.Authenticator;
import pl.edu.icm.unicore.uvos.server.saml.AttributeFilter;
import pl.edu.icm.unicore.uvos.util.AttributeTypesLoader;
import pl.edu.icm.unicore.uvos.util.Configuration;

/**
 * @author K. Benedyczak
 */
public abstract class AbstractTestBase
{
	protected UVOSManagementInterface voMan;
	protected UVOSAuthZInterface voAuthz;
	protected InternalAuthorization internalAuthz;
	protected UVOSQueryInterface voQuery;
	protected UVOSQueryHistoryInterface voQueryHistory;	
	protected SecurityContext ctx = new VirtualSecurityContextImpl(Permissions.ALL_P);
	protected Configuration config;
	protected DB db;
	protected AttributeFilter attrFilter;
	protected AttributeTypesLoader attributeLoader;
	
	@Before
	public void init()
	{
		try
		{
			connect();
		} catch (Exception e)
		{
			fail("Connection error: " + e);
			e.printStackTrace();
		}
	}

	@After
	public void cleanUp()
	{
		db.shutdown();
	}
	
	protected void connect() throws FileNotFoundException, IOException
	{
		ComponentContainer container = null;
		try
		{
			InitDB.main(new String[]{"src/test/resources/uvosServer.conf", "-b"});
			container = new ComponentContainer("src/test/resources/uvosServer.conf");
		} catch (Throwable e)
		{
			System.err.println("Severe error when starting UVOS Web Server:");
			e.printStackTrace();
			fail();
		}
		Authenticator.injectFakeContext(new VirtualSecurityContextImpl(Permissions.ALL_P));
		voAuthz = container.getComponent(UVOSAuthZInterface.class);
		internalAuthz = container.getComponent(InternalAuthorization.class);
		voMan = container.getComponent(UVOSManagementInterface.class);
		voQuery = container.getComponent(UVOSQueryInterface.class);
		voQueryHistory = container.getComponent(UVOSQueryHistoryInterface.class);
		config = container.getComponent(Configuration.class);
		db = container.getComponent(DB.class);
		attrFilter = container.getComponent(AttributeFilter.class);
		attributeLoader = container.getComponent(AttributeTypesLoader.class);
	}
	
	protected String dumpList(List<?> l)
	{
		if (l.size() == 0)
			return "EMPTY";
		String ret = l.get(0).toString();
		for (int i=1; i<l.size(); i++)
			ret = ret + ", " + l.get(i).toString();
		return ret;
	}
	
	/**
	 * createGroupStructure:
		/A
		--B/C
		--Z
	    createIdentities:
	    	2 equiv and one different (can be of the same type) idA1 idA2 and idB
	 */
	protected void createTestGI() throws UVOSException
	{
		gRoot = new Group("/");
		gA = voMan.addGroup(gRoot, "A");
		gB = voMan.addGroup(gA, "B");
		gC = voMan.addGroup(gB, "C");
		gZ = voMan.addGroup(gA, "Z");
		idA1 = new Identity(IdentityType.EMAIL, "a@a.com", "double");
		idA2 = new Identity(IdentityType.EMAIL, "agh@ex.org", "double");
		idB = new Identity(IdentityType.EMAIL, "bbb@some.dot", "single");
		voMan.addIdentity(idA1);
		voMan.addIdentity(idB);
		voMan.addIdentity(idA2, idA1);
	}
	
	protected void cleanTestGI() throws Exception
	{
		voMan.removeIdentity(idA1);
		voMan.removeIdentity(idA2);
		voMan.removeIdentity(idB);
		voMan.removeGroup(gA, true);
		voMan.purgeHistoricalData(new Date());
	}
	
	protected Group gRoot, gA, gB, gC, gZ;
	protected Identity idA1, idA2, idB;
}

==> unicore-uvos-server-1.5.1-0.src.tar.gz: src/test/java/pl/edu/icm/unicore/uvos/tests/functional/AbstractTestBase.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Sep 20, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.tests.functional;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Date;
import java.util.List;

import org.junit.After;
import org.junit.Before;

import static junit.framework.Assert.*;

import pl.edu.icm.unicore.uvos.api.Group;
import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.IdentityType;
import pl.edu.icm.unicore.uvos.api.Permissions;
import pl.edu.icm.unicore.uvos.api.exceptions.UVOSException;
import pl.edu.icm.unicore.uvos.db.DB;
import pl.edu.icm.unicore.uvos.db.InitDB;
import pl.edu.icm.unicore.uvos.engine.InternalAuthorization;
import pl.edu.icm.unicore.uvos.engine.SecurityContext;
import pl.edu.icm.unicore.uvos.engine.VirtualSecurityContextImpl;
import pl.edu.icm.unicore.uvos.engine.api.UVOSAuthZInterface;
import pl.edu.icm.unicore.uvos.engine.api.UVOSManagementInterface;
import pl.edu.icm.unicore.uvos.engine.api.UVOSQueryHistoryInterface;
import pl.edu.icm.unicore.uvos.engine.api.UVOSQueryInterface;
import pl.edu.icm.unicore.uvos.server.ComponentContainer;
import pl.edu.icm.unicore.uvos.server.idresolver.Authenticator;
import pl.edu.icm.unicore.uvos.util.AttributeFilter;
import pl.edu.icm.unicore.uvos.util.AttributeTypesLoader;
import pl.edu.icm.unicore.uvos.util.Configuration;

/**
 * @author K. Benedyczak
 */
public abstract class AbstractTestBase
{
	protected UVOSManagementInterface voMan;
	protected UVOSAuthZInterface voAuthz;
	protected InternalAuthorization internalAuthz;
	protected UVOSQueryInterface voQuery;
	protected UVOSQueryHistoryInterface voQueryHistory;	
	protected SecurityContext ctx = new VirtualSecurityContextImpl(Permissions.ALL_P);
	protected Configuration config;
	protected DB db;
	protected AttributeFilter attrFilter;
	protected AttributeTypesLoader attributeLoader;
	
	@Before
	public void init()
	{
		try
		{
			connect();
		} catch (Exception e)
		{
			fail("Connection error: " + e);
			e.printStackTrace();
		}
	}

	@After
	public void cleanUp()
	{
		db.shutdown();
	}
	
	protected void connect() throws FileNotFoundException, IOException
	{
		ComponentContainer container = null;
		try
		{
			InitDB.main(new String[]{"src/test/resources/uvosServer.conf", "-b"});
			container = new ComponentContainer("src/test/resources/uvosServer.conf");
		} catch (Throwable e)
		{
			System.err.println("Severe error when starting UVOS Web Server:");
			e.printStackTrace();
			fail();
		}
		Authenticator.injectFakeContext(new VirtualSecurityContextImpl(Permissions.ALL_P));
		voAuthz = container.getComponent(UVOSAuthZInterface.class);
		internalAuthz = container.getComponent(InternalAuthorization.class);
		voMan = container.getComponent(UVOSManagementInterface.class);
		voQuery = container.getComponent(UVOSQueryInterface.class);
		voQueryHistory = container.getComponent(UVOSQueryHistoryInterface.class);
		config = container.getComponent(Configuration.class);
		db = container.getComponent(DB.class);
		attrFilter = container.getComponent(AttributeFilter.class);
		attributeLoader = container.getComponent(AttributeTypesLoader.class);
	}
	
	protected String dumpList(List<?> l)
	{
		if (l.size() == 0)
			return "EMPTY";
		String ret = l.get(0).toString();
		for (int i=1; i<l.size(); i++)
			ret = ret + ", " + l.get(i).toString();
		return ret;
	}
	
	/**
	 * createGroupStructure:
		/A
		--B/C
		--Z
	    createIdentities:
	    	2 equiv and one different (can be of the same type) idA1 idA2 and idB
	 */
	protected void createTestGI() throws UVOSException
	{
		gRoot = new Group("/");
		gA = voMan.addGroup(gRoot, "A");
		gB = voMan.addGroup(gA, "B");
		gC = voMan.addGroup(gB, "C");
		gZ = voMan.addGroup(gA, "Z");
		idA1 = new Identity(IdentityType.EMAIL, "a@a.com", "double");
		idA2 = new Identity(IdentityType.EMAIL, "agh@ex.org", "double");
		idB = new Identity(IdentityType.EMAIL, "bbb@some.dot", "single");
		voMan.addIdentity(idA1);
		voMan.addIdentity(idB);
		voMan.addIdentity(idA2, idA1);
	}
	
	protected void cleanTestGI() throws Exception
	{
		voMan.removeIdentity(idA1);
		voMan.removeIdentity(idA2);
		voMan.removeIdentity(idB);
		voMan.removeGroup(gA, true);
		voMan.purgeHistoricalData(new Date());
	}
	
	protected Group gRoot, gA, gB, gC, gZ;
	protected Identity idA1, idA2, idB;
}
